# Quelques macros Python de mon cru
# Qui permettent d'intéragir avec la feuille courante du classeur courant
#

#importation de la fonction permettant de créer
#une session de travail avec Calc de LibreOffice
#scriptforge est une librairie de LibreOffice
#https://help.libreoffice.org/latest/en-US/text/sbasic/shared/03/lib_ScriptForge.html
from scriptforge import CreateScriptService

#première macro - écriture dans une cellule
#pas d'argument en entrée, accès direct aux feuilles
def hello_world_cell_style(args=None):
    #création d'une session
    doc = CreateScriptService("Calc")
    #écrire dans la cellule A1 de la feuille courante
    #du classeur courant
    doc.SetValue("A1","Hello World")
    doc.SetCellStyle("A1","Bad")
    #c'est une macro = une procédure, ne renvoie rien
    return None

#coordonnées sélection simple
def check_selection_simple(args=None):
    #création d'une session
    doc = CreateScriptService("Calc")
    #sélection courante
    cur_sel = doc.CurrentSelection
    #affichage dans une boîte de dialogue
    bas = CreateScriptService("Basic")
    bas.MsgBox(cur_sel)
    #fin
    return None

#check si sélection simple ou multiple
def check_selection_multiple(args=None):
    #création d'une session
    doc = CreateScriptService("Calc")
    #sélection courante
    cur_sel = doc.CurrentSelection
    #vérifier si sélection multiple ou pas
    bas = CreateScriptService("Basic")
    if (type(cur_sel) is str):        
        bas.MsgBox(cur_sel)
    else:
        bas.MsgBox(f"selection multiple : {len(cur_sel)}")
        #boucler sur chaque plage
        for i,ref_cell in enumerate(cur_sel):
            doc.SetValue(doc.Offset("A1",i,0),ref_cell)        
    #fin
    return None

#fonction pour passer en revue une plage de cellules
#du document courant
#et mettre en couleur celles qui correspondent au min
def __couleur_min(doc,the_sel):
    #calcul du min
    the_min = doc.DMin(the_sel)
    #première cellule en haut et à gauche de la sélection
    first_cell = doc.Offset(the_sel,0,0,1,1)
    #puis boucler sur la sélection
    #Height et Width indiquent le nombre de lignes et de colonnes
    for i in range(doc.Height(the_sel)):
        for j in range(doc.Width(the_sel)):
            #cellule aux coordonnées (i,j) de la sélection
            cellule = doc.Offset(first_cell,i,j)
            #valeur récupérée dans la cellule
            value = doc.GetValue(cellule)
            #vérification
            if (value == the_min):
                #mise en évidence si = au min
                doc.SetCellStyle(cellule,"Good")
    #
    return None

#minimum sur une sélection simple ou multiple
def get_min_selection(args=None):
    #création d'une session
    doc = CreateScriptService("Calc")
    #sélection courante
    cur_sel = doc.CurrentSelection
    #vérifier si sélection multiple ou pas
    if (type(cur_sel) is str):
        __couleur_min(doc,cur_sel)
    else:
        for ref_cell in cur_sel:
            __couleur_min(doc,ref_cell)
    return None
